var o=Object.defineProperty;var i=(t,e,a)=>e in t?o(t,e,{enumerable:!0,configurable:!0,writable:!0,value:a}):t[e]=a;var n=(t,e,a)=>(i(t,typeof e!="symbol"?e+"":e,a),a);import{g as c,h as d,_ as f}from"./outputWidgets.c7dcc302.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="3d55c933-d50c-4f69-af50-8dc4944fa015",t._sentryDebugIdIdentifier="sentry-dbid-3d55c933-d50c-4f69-af50-8dc4944fa015")}catch{}})();const u=[{path:"/:path(.*)*",name:"player",component:()=>f(()=>import("./Player.dfe44803.js"),["assets/Player.dfe44803.js","assets/FormRunner.ea2b0ffe.js","assets/outputWidgets.c7dcc302.js","assets/outputWidgets.bd537527.css","assets/url.8333e91c.js","assets/storage.ee8fed7f.js","assets/pubsub.d9e0718d.js","assets/jwt-decode.esm.74bd4619.js","assets/icons.b61c445b.js","assets/CircularLoading.83865111.js","assets/CircularLoading.f81b57b4.css","assets/PlayerNavbar.3a83bbbd.js","assets/PlayerNavbar.ead94b03.css","assets/ActionButton.697988ef.js","assets/ActionButton.f74e60ec.css","assets/WidgetsFrame.21e39de2.js","assets/WidgetsFrame.97ae601d.css","assets/index.ba8fce12.js","assets/Card.318fde53.js","assets/TabPane.24f70467.js","assets/hasIn.84086a40.js","assets/index.f230dddd.js","assets/Text.52e1267a.js","assets/Link.79be6b39.js","assets/Title.ec31295c.js","assets/FormRunner.8ff3f1ac.css","assets/uuid.5d0c4d2c.js","assets/asyncComputed.2f92c176.js","assets/Player.6fed9080.css"])}],g=c({history:d("/"),routes:u,scrollBehavior(t){if(t.hash)return{el:t.hash}}});async function w(){const t=await fetch("/_settings");if(!t.ok)throw new Error(await t.text());const e=await t.json();await r.init(e)}const s=class{constructor(e){this.config=e}static async init(e){s.instance=new s(e)}get showWatermark(){return this.config.show_watermark}get isStagingRelease(){return{}.VITE_ABSTRA_RELEASE==="staging"}get isLocal(){return location.origin.match(/http:\/\/localhost:\d+/)}};let r=s;n(r,"instance",null);export{r as S,g as a,u as r,w as s};
//# sourceMappingURL=index.2aefedce.js.map
