import"./outputWidgets.c7dcc302.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="e7f9fc37-f887-4299-86d8-5aa8da1a8b91",e._sentryDebugIdIdentifier="sentry-dbid-e7f9fc37-f887-4299-86d8-5aa8da1a8b91")}catch{}})();function n(e,t){return e.toLocaleString(void 0,{hour12:!1,timeZoneName:"short",day:"2-digit",month:"2-digit",year:"numeric",hour:"2-digit",minute:"2-digit",second:"2-digit",weekday:"long",...t})}export{n as g};
//# sourceMappingURL=datetime.c542c7a3.js.map
