import{d as c,ez as m,u as e,b as d,c as u,et as y,f as o,w as a,be as _,ao as p,ev as g,e as b,eB as x}from"./outputWidgets.c7dcc302.js";import"./router.cefd5d34.js";import"./jwt-decode.esm.74bd4619.js";import"./index.29a1923e.js";import{O as w}from"./organization.2f08d05f.js";import{a as h}from"./asyncComputed.2f92c176.js";import{a as k}from"./Title.ec31295c.js";import{A as B}from"./index.91f601e6.js";import{A}from"./index.badd2007.js";import{A as C}from"./Text.52e1267a.js";import{C as I}from"./Card.318fde53.js";import"./FormItem.e17f5a0a.js";import"./hasIn.84086a40.js";import"./storage.ee8fed7f.js";import"./index.1dd4f14d.js";import"./index.cf4c23b9.js";import"./record.f3b213c9.js";import"./pubsub.d9e0718d.js";import"./TabPane.24f70467.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="1cb95896-0818-4117-88bf-2df3dbce9409",t._sentryDebugIdIdentifier="sentry-dbid-1cb95896-0818-4117-88bf-2df3dbce9409")}catch{}})();const v={key:1},z={style:{display:"flex","justify-content":"flex-end","font-size":"24px"}},X=c({__name:"Billing",setup(t){const n=m().params.organizationId,{loading:l,result:f}=h(()=>w.get(n));return(D,T)=>e(l)?(d(),u(e(_),{key:0})):(d(),y("div",v,[o(e(B),{justify:"space-between",align:"center"},{default:a(()=>[o(e(k),{level:3},{default:a(()=>[p("Current plan")]),_:1}),g("",!0)]),_:1}),o(e(A),{style:{"margin-top":"0"}}),o(e(I),{style:{width:"300px"}},{default:a(()=>{var i,s;return[o(e(C),{type:"secondary"},{default:a(()=>[p("Plan")]),_:1}),b("div",z,x((s=(i=e(f))==null?void 0:i.billingMetadata)==null?void 0:s.plan),1)]}),_:1})]))}});export{X as default};
//# sourceMappingURL=Billing.866b5920.js.map
