import{Q as d}from"./outputWidgets.c7dcc302.js";import{c as s,d as i}from"./index.803f95e9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[c]="d1acac05-4534-46dd-8817-2658e1080049",e._sentryDebugIdIdentifier="sentry-dbid-d1acac05-4534-46dd-8817-2658e1080049")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:m,TimePicker:f,QuarterPicker:o,RangePicker:a}=s(i),g=d(n,{WeekPicker:r,MonthPicker:t,YearPicker:m,RangePicker:a,TimePicker:f,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(a.name,a),e.component(t.name,t),e.component(r.name,r),e.component(o.name,o),e)});export{g as D,t as M,o as Q,a as R,r as W};
//# sourceMappingURL=dayjs.f40d3b15.js.map
