import{N as l}from"./NavbarControls.57b57946.js";import{d as f,ey as _,ez as y,F as g,a as v,b as c,et as h,f as e,w as s,u as r,e as k,bo as w,ao as S,c as x,eS as T,t as q}from"./outputWidgets.c7dcc302.js";import{A as C}from"./Text.52e1267a.js";import{T as I,A as a}from"./TabPane.24f70467.js";import{c as A}from"./index.6ca484ad.js";import"./asyncComputed.2f92c176.js";import"./index.2aefedce.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.b32d63ba.js";import"./SaveButton.vue_vue_type_script_setup_true_lang.b28bd562.js";import"./ant-design.362be163.js";import"./index.c8fd351b.js";import"./Modal.fa1b2cba.js";import"./storage.ee8fed7f.js";import"./Link.79be6b39.js";import"./index.f230dddd.js";import"./Title.ec31295c.js";import"./index.d6544e82.js";import"./workspaces.2639d2d4.js";import"./record.f3b213c9.js";import"./pubsub.d9e0718d.js";import"./url.8333e91c.js";import"./popupNotifcation.106e4e08.js";import"./CircularLoading.83865111.js";import"./icons.b61c445b.js";import"./index.91f601e6.js";import"./hasIn.84086a40.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="df032226-105e-41cc-bb14-57fc443be63c",o._sentryDebugIdIdentifier="sentry-dbid-df032226-105e-41cc-bb14-57fc443be63c")}catch{}})();const B={class:"content"},D=f({__name:"Settings",setup(o){const t=_(),n=y();function m(){t.push({name:"home"})}const p=g(()=>{switch(n.name){case"settingsStyle":return"style";case"settingsSidebar":return"sidebar";case"settingsRequirements":return"requirements";default:return}});function u(i){switch(i){case"style":t.push({name:"settingsStyle"});break;case"sidebar":t.push({name:"settingsSidebar"});break;case"requirements":t.push({name:"settingsRequirements"});break}}return(i,N)=>{const d=v("router-view");return c(),h(w,null,[e(r(A),{style:{padding:"5px 25px"},onBack:m},{extra:s(()=>[e(l,{"show-v-s-code-button":"","show-save-button":""})]),avatar:s(()=>[e(r(C),null,{default:s(()=>[S("Settings")]),_:1})]),footer:s(()=>[e(r(I),{"active-key":p.value,onChange:u},{default:s(()=>[e(r(a),{key:"style",tab:"Style"}),e(r(a),{key:"sidebar",tab:"Sidebar"}),e(r(a),{key:"requirements",tab:"Requirements"})]),_:1},8,["active-key"])]),_:1}),k("div",B,[e(d,null,{default:s(({Component:b})=>[(c(),x(T(b)))]),_:1})])],64)}}});const ae=q(D,[["__scopeId","data-v-772f4b10"]]);export{ae as default};
//# sourceMappingURL=Settings.39aa7050.js.map
