import{_ as B}from"./logo.084e5d7c.js";import{t as C,b as r,et as y,eC as I,eD as w,e as h,d as k,ey as L,a as D,u as e,c,be as S,w as t,f as a,ao as l,eB as i,bM as f,cA as b,cw as N,eJ as V,eA as R,f0 as T,bo as E,ev as M}from"./outputWidgets.c7dcc302.js";import{b as g}from"./router.cefd5d34.js";import{a as P}from"./asyncComputed.2f92c176.js";import{A as $}from"./Text.52e1267a.js";import{A as j,B as F,a as H,c as J}from"./index.6ca484ad.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[s]="e4e5a1c9-6e31-47b3-890c-2e83dc0564d7",o._sentryDebugIdIdentifier="sentry-dbid-e4e5a1c9-6e31-47b3-890c-2e83dc0564d7")}catch{}})();const U={},A=o=>(I("data-v-439be421"),o=o(),w(),o),q={class:"logo"},z=A(()=>h("img",{class:"logo-img",src:B,alt:"Abstra cloud logo"},null,-1)),G=A(()=>h("span",null,"Abstra Cloud",-1)),K=[z,G];function O(o,s){return r(),y("div",q,K)}const Q=C(U,[["render",O],["__scopeId","data-v-439be421"]]),W=k({__name:"LoginBlock",setup(o){function s(p){const m=p.split("@")[0];return V.exports.kebabCase(m).toUpperCase().split("-").slice(0,2).map(_=>_[0]).join("")}const d=L(),{result:n,loading:u,refetch:v}=P(async()=>g.getAuthor());function x(){g.removeAuthor(),v(),d.push({name:"login"})}return(p,m)=>{const _=D("router-link");return e(u)?(r(),c(e(S),{key:0})):e(n)?(r(),c(e(N),{key:1,placement:"bottomRight"},{content:t(()=>[a(e(b),{direction:"vertical"},{default:t(()=>[a(e($),null,{default:t(()=>[l(i(e(n).claims.email),1)]),_:1}),a(e(f),{onClick:x},{default:t(()=>[l("Logout")]),_:1})]),_:1})]),default:t(()=>[a(e(b),{align:"center",style:{cursor:"pointer"}},{default:t(()=>[a(e(j),null,{default:t(()=>[l(i(s(e(n).claims.email)),1)]),_:1})]),_:1})]),_:1})):(r(),c(e(f),{key:2},{default:t(()=>[a(_,{to:"/login"},{default:t(()=>[l("Login")]),_:1})]),_:1}))}}}),ae=k({__name:"Navbar",props:{breadcrumb:{}},setup(o){return(s,d)=>(r(),c(e(J),{style:{padding:"5px 25px"}},{breadcrumb:t(()=>[s.breadcrumb?(r(),c(e(F),{key:0},{default:t(()=>[(r(!0),y(E,null,R(s.breadcrumb,(n,u)=>(r(),c(e(H),{key:u},{default:t(()=>[a(e(T),{to:n.path},{default:t(()=>[l(i(n.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):M("",!0)]),title:t(()=>[a(Q)]),extra:t(()=>[a(W)]),_:1}))}});export{ae as _};
//# sourceMappingURL=Navbar.vue_vue_type_script_setup_true_lang.608e5ed3.js.map
