import{cu as n}from"./outputWidgets.c7dcc302.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="941c5093-9bff-4a10-86c2-6df1b72a45c0",e._sentryDebugIdIdentifier="sentry-dbid-941c5093-9bff-4a10-86c2-6df1b72a45c0")}catch{}})();const t=(e,r)=>{n.error({message:e,description:r})};export{t as p};
//# sourceMappingURL=popupNotifcation.106e4e08.js.map
