import"./outputWidgets.c7dcc302.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="e6afe43e-3d0b-49eb-90b8-b89c1327339b",r._sentryDebugIdIdentifier="sentry-dbid-e6afe43e-3d0b-49eb-90b8-b89c1327339b")}catch{}})();class s{static get(e){try{const t=localStorage.getItem(e);return t&&JSON.parse(t)}catch{return null}}static set(e,t){localStorage.setItem(e,JSON.stringify(t))}static pop(e){const t=s.get(e);return s.remove(e),t}static remove(e){localStorage.removeItem(e)}}export{s as S};
//# sourceMappingURL=storage.ee8fed7f.js.map
