import"./outputWidgets.c7dcc302.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="e31750fd-ba9a-447d-bf72-75a21ecf0c8a",e._sentryDebugIdIdentifier="sentry-dbid-e31750fd-ba9a-447d-bf72-75a21ecf0c8a")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.8333e91c.js.map
