import{a as e,A as a,B as s}from"./Text.52e1267a.js";import{A as o}from"./Link.79be6b39.js";import{a as r,A as i}from"./Title.ec31295c.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[t]="e4921849-fb4c-4559-9087-069e046e07c1",n._sentryDebugIdIdentifier="sentry-dbid-e4921849-fb4c-4559-9087-069e046e07c1")}catch{}})();e.Text=a;e.Title=r;e.Paragraph=i;e.Link=o;e.Base=s;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,a),n.component(e.Title.displayName,r),n.component(e.Paragraph.displayName,i),n.component(e.Link.displayName,o),n};
//# sourceMappingURL=index.f230dddd.js.map
