import{t as o,a as r,b as i,c,i as d,T as p,j as f,P as _,C as u,M as b,s as l,k as s,l as g,m,n as y,p as v}from"./outputWidgets.c7dcc302.js";import{s as w,a}from"./index.2aefedce.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="bcf68078-7fe2-4f26-b050-e264eaa14dab",e._sentryDebugIdIdentifier="sentry-dbid-bcf68078-7fe2-4f26-b050-e264eaa14dab")}catch{}})();const h={};function I(e,t){const n=r("router-view");return i(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const k=o(h,[["render",I]]);class x{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await w();const e=d({render:()=>g(k)});p.init(),f(e,a),x.init(),e.use(a),e.use(_),e.mount("#app"),e.component("VSelect",u),e.component("Markdown",b),e.component("Message",l),s(e,m),s(e,y),s(e,v)})();
//# sourceMappingURL=player.f7da8b65.js.map
