import"./outputWidgets.c7dcc302.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},x=new Error().stack;x&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[x]="1de86e2b-9660-4a72-be48-150aa7ee8947",e._sentryDebugIdIdentifier="sentry-dbid-1de86e2b-9660-4a72-be48-150aa7ee8947")}catch{}})();const d=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(e){const x=Math.random()*16|0;return(e=="x"?x:x&3|8).toString(16)});export{d as u};
//# sourceMappingURL=uuid.5d0c4d2c.js.map
