import{t as n,b as s,et as o}from"./outputWidgets.c7dcc302.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="1a919d9a-3182-4b43-810e-15161d133b79",e._sentryDebugIdIdentifier="sentry-dbid-1a919d9a-3182-4b43-810e-15161d133b79")}catch{}})();const r={},a={class:"organization-settings"};function d(e,t){return s(),o("div",a,"Organization settings")}const f=n(r,[["render",d]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.d732d56a.js.map
