import{S as p}from"./Sidebar.06cd0cc5.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.608e5ed3.js";import{G as d,H as l,I as u}from"./icons.b61c445b.js";import{d as b,ez as f,F as g,a as _,b as y,c as v,w as a,f as r}from"./outputWidgets.c7dcc302.js";import{a as z}from"./asyncComputed.2f92c176.js";import"./router.cefd5d34.js";import"./jwt-decode.esm.74bd4619.js";import"./index.29a1923e.js";import{O as w}from"./organization.2f08d05f.js";import{B as I}from"./BaseLayout.7c1db457.js";import"./index.7279efc8.js";import"./logo.084e5d7c.js";import"./Text.52e1267a.js";import"./index.6ca484ad.js";import"./FormItem.e17f5a0a.js";import"./hasIn.84086a40.js";import"./storage.ee8fed7f.js";import"./index.1dd4f14d.js";import"./index.cf4c23b9.js";import"./record.f3b213c9.js";import"./pubsub.d9e0718d.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="bcc4d072-4e36-4557-8678-9e3a7d53144f",o._sentryDebugIdIdentifier="sentry-dbid-bcc4d072-4e36-4557-8678-9e3a7d53144f")}catch{}})();const K=b({__name:"Organization",setup(o){const n=f().params.organizationId,{result:t}=z(()=>w.get(n)),i=g(()=>t.value?[{label:"My organizations",path:"/organizations"},{label:t.value.name,path:`/organizations/${t.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing"}]}];return(h,B)=>{const m=_("router-view");return y(),v(I,null,{navbar:a(()=>[r(c,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:a(()=>[r(p,{class:"sidebar",sections:s})]),content:a(()=>[r(m)]),_:1})}}});export{K as default};
//# sourceMappingURL=Organization.343ab170.js.map
