import{F as t}from"./Form.698fed96.js";import{aJ as r,cj as n}from"./outputWidgets.c7dcc302.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="ac5cb866-cc86-4e47-9568-df66727b2ae3",e._sentryDebugIdIdentifier="sentry-dbid-ac5cb866-cc86-4e47-9568-df66727b2ae3")}catch{}})();t.useInjectFormItemContext=r;t.ItemRest=n;t.install=function(e){return e.component(t.name,t),e.component(t.Item.name,t.Item),e.component(n.name,n),e};
//# sourceMappingURL=index.326684eb.js.map
